==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/SubjectKeyIdentifier.h <==
// public class gnu.java.security.x509.ext.SubjectKeyIdentifier

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class bf7a03c5b1f205de gnu_java_security_x509_ext_SubjectKeyIdentifier
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_SubjectKeyIdentifier_H_
#define _JC_gnu_java_security_x509_ext_SubjectKeyIdentifier_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_refs	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_nonrefs	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$refs	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$refs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$nonrefs	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object;

typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$fields_struct	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vmethods	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtable	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtype	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24SubjectKeyIdentifier;
};
extern _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$fields_struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object *, struct _jc_byte_array *);

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method$getKeyIdentifier$142fba11413589b7(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method_info$getKeyIdentifier$142fba11413589b7;
extern _jc_method _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vmethods {
	_jc_byte_array	*(*getKeyIdentifier$142fba11413589b7)(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vmethods	gnu_java_security_x509_ext_SubjectKeyIdentifier;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_refs {
	_jc_byte_array	*keyIdentifier;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$refs {
    _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_refs	gnu_java_security_x509_ext_SubjectKeyIdentifier;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_nonrefs	gnu_java_security_x509_ext_SubjectKeyIdentifier;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object {
	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtype _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_SubjectKeyIdentifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_SubjectKeyIdentifier_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/SubjectKeyIdentifier.h <==
// public class gnu.java.security.x509.ext.SubjectKeyIdentifier

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class bf7a03c5b1f205de gnu_java_security_x509_ext_SubjectKeyIdentifier
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_SubjectKeyIdentifier_H_
#define _JC_gnu_java_security_x509_ext_SubjectKeyIdentifier_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_refs	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_nonrefs	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$refs	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$refs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$nonrefs	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object;

typedef struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$fields_struct	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vmethods	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtable	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtype	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24SubjectKeyIdentifier;
};
extern _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$fields_struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method$getKeyIdentifier$142fba11413589b7(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method_info$getKeyIdentifier$142fba11413589b7;
extern _jc_method _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vmethods {
	_jc_byte_array	*(*getKeyIdentifier$142fba11413589b7)(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vmethods	gnu_java_security_x509_ext_SubjectKeyIdentifier;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_refs {
	_jc_byte_array	*keyIdentifier;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$refs {
    _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_refs	gnu_java_security_x509_ext_SubjectKeyIdentifier;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$sub_nonrefs	gnu_java_security_x509_ext_SubjectKeyIdentifier;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$object {
	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$vtype _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_SubjectKeyIdentifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_SubjectKeyIdentifier$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_SubjectKeyIdentifier_H_ */
